@@ -6,7 +6,7 @@ use Time::Local;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 my %months_map = (
     'Jan' => 0, 'Feb' => 1, 'Mar' => 2,
@@ -21,13 +21,19 @@ sub new($$;%)
     croak "new() requires one argument: file" unless defined $file;
     %data = () unless %data;
     if(not defined $data{year}) {
-	$data{year} = (localtime(time))[5]+1900;
+        $data{year} = (localtime(time))[5]+1900;
     }
     $data{_repeat}=0;
 
-    # open file
-    $data{file}=gensym;
-    open($data{file}, "<$file") or croak "can't open $file: $!";
+    if(ref $file eq 'File::Tail') {
+        $data{filetail} = 1;
+        $data{file} = $file;
+    }
+    else {
+        $data{file}=gensym;
+        open($data{file}, "<$file") or croak "can't open $file: $!";
+    }
+
     return bless \%data, $class;
 }
 
@@ -35,7 +41,12 @@ sub _next_line($)
 {
     my $self = shift;
     my $f = $self->{file};
-    return <$f>;
+    if(defined $self->{filetail}) {
+        return $f->read;
+    }
+    else {
+        return <$f>;
+    }
 }
 
 sub next($)
@@ -43,80 +54,86 @@ sub next($)
     my ($self) = @_;
 
     while($self->{_repeat}>0) {
-	$self->{_repeat}--;
-	return $self->{_last_data};
+        $self->{_repeat}--;
+        return $self->{_last_data};
     }
 
     line: while(my $str = $self->_next_line()) {
-	# date, time and host 
-	$str =~ /^
-	    (\w{3})\s+(\d+)   # date  -- 1, 2
-	    \s
-	    (\d+):(\d+):(\d+) # time  -- 3, 4, 5
-	    \s
-	    ([-\w\.]+)        # host  -- 6
-	    \s+
-	    (.*)              # text  -- 7
-	    $/x or do
-	{
-	    carp "line not in syslog format: $str";
-	    next line;
-	};
-	
-	my $mon = $months_map{$1};
-	defined $mon or croak "unknown month $1\n";
+        # date, time and host 
+        $str =~ /^
+            (\w{3})\s+(\d+)   # date  -- 1, 2
+            \s
+            (\d+):(\d+):(\d+) # time  -- 3, 4, 5
+            \s
+            ([-\w\.]+)        # host  -- 6
+            \s+
+            (.*)              # text  -- 7
+            $/x or do
+        {
+            carp "line not in syslog format: $str";
+            next line;
+        };
+        
+        my $mon = $months_map{$1};
+        defined $mon or croak "unknown month $1\n";
 
-	# year change
-	$self->{year}++ if defined $self->{_last_mon}
-	    and $self->{_last_mon} > $mon;
-	$self->{_last_mon} = $mon;
+        # year change
+        $self->{year}++ if defined $self->{_last_mon}
+            and $self->{_last_mon} > $mon;
+        $self->{_last_mon} = $mon;
 
-	# convert to unix time
-	my $time = timelocal($5,$4,$3,$2,$mon,$self->{year}-1900);
+        # convert to unix time
+        my $time;
+        if($self->{GMT}) {
+            $time = timegm($5,$4,$3,$2,$mon,$self->{year}-1900);
+        }
+        else {
+            $time = timelocal($5,$4,$3,$2,$mon,$self->{year}-1900);
+        }
 
-	my ($host, $text) = ($6, $7);
-	
-	# last message repeated ... times
-	if($text =~ /^last message repeated (\d+) time/) {
-	    next line if defined $self->{repeat} and not $self->{repeat};
+        my ($host, $text) = ($6, $7);
+        
+        # last message repeated ... times
+        if($text =~ /^last message repeated (\d+) time/) {
+            next line if defined $self->{repeat} and not $self->{repeat};
             next line if not defined $self->{_last_data};
-	    $1 > 0 or do {
-		carp "last message repeated 0 or less times??";
-		next line;
-	    };
-	    $self->{_repeat}=$1-1;
-	    return $self->{_last_data};
-	}
+            $1 > 0 or do {
+                carp "last message repeated 0 or less times??";
+                next line;
+            };
+            $self->{_repeat}=$1-1;
+            return $self->{_last_data};
+        }
 
-	# some systems send over the network their
-	# hostname prefixed to the text. strip that.
-	$text =~ s/^[-\w+\.]+\s+//;
+        # some systems send over the network their
+        # hostname prefixed to the text. strip that.
+        $text =~ s/^[-\w+\.]+\s+//;
 
-	# snort log
-	$text =~ /^
-	    (\S+?)          # program   -- 1
-	    (?:\[(\d+)\])?  # PID       -- 2
-	    :\s+
-            (?:\[ID\ (\d+)\ ([a-z0-9]+)\.([a-z0-9]+)\]\ )?   # Solaris 8 "message id" -- 3, 4, 5
-	    (.*)            # text      -- 6
-	    $/x or do
-	{
-	    carp "line not in syslog format: $str";
-	    next line;
-	};
+        # snort log
+        $text =~ /^
+            (\S+?)          # program   -- 1
+            (?:\[(\d+)\])?  # PID       -- 2
+            :\s+
+            (?:\[ID\ (\d+)\ ([a-z0-9]+)\.([a-z]+)\]\ )?   # Solaris 8 "message id" -- 3, 4, 5
+            (.*)            # text      -- 6
+            $/x or do
+        {
+            carp "line not in syslog format: $str";
+            next line;
+        };
 
-	$self->{_last_data} = {
-	    timestamp => $time,
-	    host      => $host,
-	    program   => $1,
-	    pid       => $2,
+        $self->{_last_data} = {
+            timestamp => $time,
+            host      => $host,
+            program   => $1,
+            pid       => $2,
             msgid     => $3,
             facility  => $4,
             level     => $5,
             text      => $6,
         };
 
-	return $self->{_last_data};
+        return $self->{_last_data};
     }
     return undef;
 }
@@ -149,9 +166,11 @@ with Unix-timestamp, host, program, pid and text returned in a hash-reference.
 =head1 Constructing a Parser
 
 B<new> requires as first argument a file-name for the syslog-file to be parsed.
+Alternatively, you can pass a File::Tail object as first argument, in which
+case the I<read> method will be called to get lines to process.
 
-After the file-name you can specify options as a hash. The following options
-are defined:
+After the file-name (or File::Tail object), you can specify options as a hash.
+The following options are defined:
 
 =over 8
 
@@ -161,6 +180,11 @@ Syslog files usually do store the time of the event without year. With this
 option you can specify the start-year of this log. If not specified, it will be
 set to the current year.
 
+=item B<GMT>
+
+If this option is set, the time in the syslog will be converted assuming it is
+GMT time instead of local time.
+
 =item B<repeat>
 
 Parse::Syslog will by default repeat xx times events that are followed by
